@@ -2,7 +2,7 @@
 from __future__ import absolute_import
 from .event_emitter import EventEmitter
 from . import has_bin
-import parser
+from . import parser
 import logging
 
 logger = logging.getLogger(__name__)
@@ -47,6 +47,14 @@ class Socket(EventEmitter):
         self.disconnected = False
 
     def emit(self, event, *args):
+        """
+        the interface for both sending messages and normal event notification
+        If the event is predefined events, then emit the event to listeners, otherwise
+        send it out as packet
+        :param event: Event name
+        :param args: The list of data for the event. emit('message', 'hello') or emit('message', {'content':'wonderful'})
+        :return: None
+        """
         if event in events:
             super(Socket, self).emit(event, *args)
 
@@ -58,8 +66,6 @@ class Socket(EventEmitter):
 
             packet['data'] = [event] + list(args)
 
-            # TODO ADD ack callback
-
             if len(self.rooms_send_to) > 0 or 'broadcast' in self.flags:
                 self.adapter.broadcast(packet, {
                     'except': [self.id],
@@ -70,22 +76,29 @@ class Socket(EventEmitter):
                 self.packet(packet)
 
         self.rooms_send_to = []
-        self.flags = {}
+        self.flags = set()
 
     def to(self, name):
+        """
+        Mark that the next event should send to which room
+        :param name: The name of the room
+        :return: self. Easier for chaining. socket.to('chat').emit('message', 'hello chat')
+        """
         if name not in self.rooms_send_to:
             self.rooms_send_to.append(name)
 
         return self
 
     def send(self, *args):
+
         self.emit('message', *args)
         return self
 
     write = send
 
     def packet(self, p, pre_encoded=False):
-        p['nsp'] = self.namespace.name
+        if type(p) is dict:
+            p['nsp'] = self.namespace.name
         self.client.packet(p, pre_encoded)
 
     def join(self, room, callback=None):
